.. _refman_ext_datagen:

DataGen
=======

This section contains source code documentation of DataGen extensions.

.. _refman_ext_datagen_datagen:

datagen
^^^^^^^

.. automodule:: hydratk.extensions.datagen.datagen
   :member-order: bysource
   
.. _refman_ext_datagen_bootstrapper: 

bootstrapper
^^^^^^^^^^^^

.. automodule:: hydratk.extensions.datagen.bootstrapper
   :member-order: bysource    

.. _refman_ext_datagen_asn1:

asn1
^^^^

.. automodule:: hydratk.extensions.datagen.asn1codec
   :member-order: bysource

.. _refman_ext_datagen_jsongen:

jsongen
^^^^^^^

.. automodule:: hydratk.extensions.datagen.jsongen
   :member-order: bysource

.. _refman_ext_datagen_xmlgen:

xmlgen
^^^^^^

.. automodule:: hydratk.extensions.datagen.xmlgen
   :member-order: bysource
   
.. _refman_ext_datagen_serializer:    
   
serializer
^^^^^^^^^^

.. automodule:: hydratk.extensions.datagen.serializer
   :member-order: bysource      
   
.. _refman_ext_datagen_selenium:     
   
selenium
^^^^^^^^

.. automodule:: hydratk.extensions.datagen.adapters.selenium.adapter
   :member-order: bysource     